@@ -15,11 +15,11 @@ class TestSimpleThreadsRunner(TestCase):
         time.sleep(1)
 
     def test_01_run_threads(self):
-        sr = SimpleThreadsRunner(self.n_print)
+        sr = SimpleThreadsRunner()
         # LifoQueue
         sr._queue = queue.LifoQueue()
-        sr.run_threads(5, iter_data=self.actions)
+        sr.run_threads(5, fn=self.n_print, iter_data=self.actions)
 
     def test_02_batch_run_threads(self):
-        sr = SimpleThreadsRunner(self.n_print)
-        sr.run_threads(5, iter_data=self.actions, batch_size=10)
+        sr = SimpleThreadsRunner()
+        sr.run_threads(5, fn=self.n_print, iter_data=self.actions, batch_size=10)
